package com.cgi.cihr.gui;

import java.awt.Toolkit;
import java.awt.event.ActionEvent;
import java.io.IOException;
import java.util.Properties;

import javax.swing.AbstractAction;
import javax.swing.JFrame;
import javax.swing.JMenu;
import javax.swing.JMenuBar;
import javax.swing.JMenuItem;
import javax.swing.JSeparator;
import javax.swing.KeyStroke;
import javax.swing.text.DefaultEditorKit;

import com.cgi.cihr.EISImportAction;

/**
 * Create the menus.
 * 
 * @author tomas.hansson
 */
public class EISMenus extends JMenuBar {
	EISColourPane colourPane;
	
	/**
	 * Construct the menus.
	 * 
	 * @param parent
	 * @param cp
	 */
	public EISMenus(JFrame parent, EISColourPane cp) {
		colourPane = cp;
		
		// File menu
		JMenu fileMenu = new JMenu("File");
		fileMenu.add(new EISImportAction(parent, cp));		
		fileMenu.add(new JSeparator());		
		fileMenu.add(new ExitAction());
		
		// Edit menu
		JMenu editMenu = new JMenu("Edit");
		JMenuItem item = new JMenuItem(cp.getActionMap().get(DefaultEditorKit.copyAction));
		item.setText("Copy");
		item.setAccelerator(KeyStroke.getKeyStroke('C', 
				Toolkit.getDefaultToolkit().getMenuShortcutKeyMask(), false));
		editMenu.add(item);
		
		// Help menu
		JMenu helpMenu = new JMenu("Help");
		helpMenu.add(new HelpAction());
		helpMenu.add(new JSeparator());
		helpMenu.add(new AboutAction());
		
		// Add the items to the menu
		add(fileMenu);
		add(editMenu);
		add(helpMenu);
	}
	
	// Inner classes
	class ExitAction extends AbstractAction {
		public ExitAction() {
			super("Exit");
		}
		
		public void actionPerformed(ActionEvent ev) {
			System.exit(0);
		}
	}

	class HelpAction extends AbstractAction {
		public HelpAction() {
			super("Help");
		}
		
		public void actionPerformed(ActionEvent ev) {
			colourPane.writelnError("Not implemented.");
		}
	}
	
	class AboutAction extends AbstractAction {
		public AboutAction() {
			super("About");
		}
		
		public void actionPerformed(ActionEvent ev) {
			// Read properties
			try {
				Properties props = new Properties();
				props.load(ClassLoader.getSystemResourceAsStream("eis.properties"));
				
				colourPane.writelnError(props.getProperty("about"));
			} catch (IOException e) {
				colourPane.writeException(e);
			}

		}
	}
}
