package com.cgi.tools;

import java.io.BufferedReader;
import java.io.File;
import java.io.FileReader;
import java.io.IOException;
import java.io.Reader;

/**
 * Class to read fixed-sized column files.
 * 
 * @author tomas.hansson
 */
public class ColumnReader extends BufferedReader {
	private int[] widths;
	
	/**
	 * File constructor.
	 * 
	 * @param colDefs
	 * @param file
	 * @throws IOException
	 */
	public ColumnReader(int[] colDefs, File file) throws IOException {
		super(new FileReader(file));
		this.widths = colDefs;
	}

	/**
	 * Filename constructor.
	 * 
	 * @param colDefs
	 * @param filename
	 * @throws IOException
	 */
	public ColumnReader(int[] colDefs, String filename) throws IOException {
		super(new FileReader(filename));
		this.widths = colDefs;
	}
	
	/**
	 * Reader constructor.
	 * 
	 * @param colWidths
	 * @param colReader
	 */
	public ColumnReader(int[] colWidths, Reader colReader) {
		super(colReader);
	}
	
	/**
	 * Read the line into a string array.
	 * 
	 * @return String[]
	 * @throws IOException
	 */
	public String[] readLines() throws IOException {
		String line = readLine();
		
		if (line == null) {
			return null;
		}
		
		String[] cols = new String[this.widths.length];
		
		int pos = 0;
		
		for (int i = 0; i < this.widths.length; i++) {
			if (line.trim().length() == 0) {
				continue;
			}
			
			int colWidth = this.widths[i];
			
			try {
				String val = line.substring(pos, pos + colWidth);
				cols[i] = val.trim();
			} catch (IndexOutOfBoundsException e) {
				return null;
			}
			
			pos += colWidth;
		}
		
		return cols;
	}
	
	/**
	 * Close the reader.
	 * 
	 * @throws IOException
	 */
	public void close() throws IOException {
		super.close();
	}
}
